# stock-clock项目说明

## 项目介绍

## 文件组织

### 1.content  

### 2.Utils 
用于存放工具：  
DataUtils-数据管理的工具类；  
AnalyzeUtils-数据分析的工具类，用于存放模型的初始代码（由本地同步上传），在线学习代码和自动化训练&结果保存的代码； 

### PyScript
用于存放Python脚本，crontab自动运行  
